ChangeLog
=========

Changes from 0.6.5 to 1.0 (04/01/2015)
--------------------------------------

* First release as standalone package (*QtSix*)
* Package name changed form `qt` to `qtsix'
* Added support form PyQt5_ and switch to PyQt5_ API.
  Now the reference API exposed by *QtSix* is the one provided by the
  PyQt5_ package.


Version 0.6.5 (13/11/2011)
--------------------------

Initial release as part of the GSDView_ project.

This version only support PyQt4_ and PySide_ and used the Pyside_ API.


.. _PyQt5: http://www.riverbankcomputing.com/software/pyqt/intro
.. _PyQt4: http://www.riverbankcomputing.com/software/pyqt/intro
.. _PySide: http://pyside.org

